[![PyPI version](https://img.shields.io/pypi/v/murefi)](https://pypi.org/project/murefi)
[![pipeline](https://github.com/jubiotech/murefi/workflows/pipeline/badge.svg)](https://github.com/jubiotech/murefi/actions)
[![coverage](https://codecov.io/gh/jubiotech/murefi/branch/master/graph/badge.svg)](https://codecov.io/gh/jubiotech/murefi)
[![documentation](https://readthedocs.org/projects/murefi/badge/?version=latest)](https://murefi.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/353352505.svg)](https://zenodo.org/badge/latestdoi/353352505)

# `murefi`
This package provides useful data structures and mapping objects for __mu__&#x200b;lti-__re__&#x200b;plicate __fi__&#x200b;tting, mainly of ordinary differential euqation (ODE) models. 
To see implementation examples & excercises, you can go to [notebooks/](notebooks).

# Installation
`murefi` is released on [PyPI](https://pypi.org/project/murefi/):

```
pip install murefi
```
# Documentation
Read the package documentation [here](https://murefi.readthedocs.io/en/latest/?badge=latest).

# Usage and Citing
`murefi` is licensed under the [GNU Affero General Public License v3.0](https://github.com/jubiotech/murefi/blob/master/LICENSE).

Head over to Zenodo to [generate a BibTeX citation](https://doi.org/10.5281/zenodo.4652911) for the latest release.
